@@ -1,5 +1,5 @@
 #pragma once
 
-#include "pt2-clone/pt2_structs.h"
+#include "pt2-clone.h"
 
 module_t * get_mod(SEXP mod);
