@@ -1,31 +1,28 @@
 #include <cpp11.hpp>
 #include <vector>
 #include "samples.h"
-#include "pt2-clone/pt2_helpers.h"
-#include "pt2-clone/pt2_config.h"
-#include "pt2-clone/pt2_structs.h"
-#include "pt2-clone/pt2_sample_loader.h"
+#include "pt2-clone.h"
 using namespace cpp11;
 
 #define PLAYBACK_FREQ 16574 /* C-3, period 214 */
 
 [[cpp11::register]]
-SEXP open_samp_(raws data) {
+raws open_samp_(raws data) {
   uint8_t * buffer = (uint8_t *)RAW(as_sexp(data));
   uint32_t dat_size = data.size();
   
   moduleSample_t *s = (moduleSample_t *)malloc(sizeof (moduleSample_t));
-  if (s == NULL) Rf_error("Out of memory");
+  if (s == NULL) stop("Out of memory");
   int8_t *smpDat = (int8_t *)malloc(config.maxSampleLength);
   if (smpDat == NULL) {
     free(s);
-    Rf_error("Out of memory");
+    stop("Out of memory");
   }
   
   if (!loadSample2(buffer, dat_size, s, smpDat) || s->length == 0) {
     free(s);
     free(smpDat);
-    Rf_error("Failed to read sample");
+    stop("Failed to read sample");
   }
   writable::raws output((R_xlen_t)(s->length));
   
@@ -42,7 +39,7 @@ SEXP open_samp_(raws data) {
 }
 
 [[cpp11::register]]
-SEXP sample_file_format_(SEXP input, std::string file_type) {
+raws sample_file_format_(SEXP input, std::string file_type) {
   raws input_r(input);
   int8_t * ibuffer      = (int8_t *)RAW(input_r);
   list sample_info      = list(input_r.attr("sample_info"));
@@ -55,15 +52,19 @@ SEXP sample_file_format_(SEXP input, std::string file_type) {
   
   writable::raws output((R_xlen_t)0);
   
-  if (file_type.compare("IFF")) {
+  if (file_type == "IFF") {
     // IFF file size
-    // FORM + 8SVX + VHDR + 20 + NAME + namelen + ANNO + ProTrackR2 + BODY + samplelen
-    uint32_t file_size = 16 * 4 + 8 + 20 + 10 + sampleLength + (sampleLength & 1);
+    // FORM + 8SVX + VHDR + 20 + (NAME + namelen) + ANNO + ProTrackR2 + BODY + samplelen
+    // 6 chunk headers of which 5 have also length 6 * 4 + 5 * 4
+    // VHDR always has 20 bytes
+    // ANNO always has 10 bytes
+    // NAME and BODY have variable length
+    uint32_t file_size = 6 * 4 + 5 * 4 + 20 + 10 + sampleLength + (sampleLength & 1);
     if (namelen > 0) {
-      file_size += 16 + (namelen + (namelen&1));
+      file_size += (namelen + (namelen&1));
     }
     
-    int32_t align = ((uint32_t)(file_size/4))*4;
+    int32_t align = ((uint32_t)(file_size/2))*2;
     
     writable::raws output((R_xlen_t)align);
     uint8_t * buffer = (uint8_t *)RAW(as_sexp(output));
@@ -125,7 +126,8 @@ SEXP sample_file_format_(SEXP input, std::string file_type) {
     
     if (sampleLength & 1) buffer[0] = 0;
     output.resize(file_size);
-  } else if (file_type.compare("WAV")) {
+    return output;
+  } else if (file_type == "WAV") {
     wavHeader_t wavHeader;
     samplerChunk_t samplerChunk;
     mptExtraChunk_t mptExtraChunk;
@@ -147,7 +149,7 @@ SEXP sample_file_format_(SEXP input, std::string file_type) {
     wavHeader.byteRate = wavHeader.sampleRate * wavHeader.numChannels * wavHeader.bitsPerSample / 8;
     wavHeader.blockAlign = wavHeader.numChannels * wavHeader.bitsPerSample / 8;
     
-    if (loopStart+loopLength > 2) // loop enabled?
+    if (loopStart + loopLength > 2) // loop enabled?
     {
       wavHeader.chunkSize += sizeof (samplerChunk_t);
       samplerChunk.chunkID = 0x6C706D73; // "smpl"
@@ -162,7 +164,7 @@ SEXP sample_file_format_(SEXP input, std::string file_type) {
     // set ModPlug Tracker chunk (used for sample volume only in this case)
     wavHeader.chunkSize += sizeof (mptExtraChunk);
     mptExtraChunk.chunkID = 0x61727478; // "xtra"
-    mptExtraChunk.chunkSize = sizeof (mptExtraChunk) - 4 - 4;
+    mptExtraChunk.chunkSize = sizeof (mptExtraChunk) - 2*sizeof(uint32_t); // -8 because it doesn't include chunkID and chunkSize
     mptExtraChunk.defaultPan = 128; // 0..255
     mptExtraChunk.defaultVolume = volume * 4; // 0..256
     mptExtraChunk.globalVolume = 64; // 0..64
@@ -194,10 +196,10 @@ SEXP sample_file_format_(SEXP input, std::string file_type) {
     }
     
     memcpy(buffer, &mptExtraChunk, sizeof (mptExtraChunk));
-    
+    return output;
   } else {
-    Rf_error("Writing file type '%s' is not supported.",
-             file_type.c_str());
+    stop("Writing file type '%s' is not supported.",
+         file_type.c_str());
   }
-  return output;
+  return R_NilValue;
 }
